FulfillmentInstruction : Contains the instructions about the fulfillment like where should it be fulfilled from.
Fields
fulfillment_supply_source_id: Option<String>Denotes the recommended sourceId where the order should be fulfilled from.
Implementations
sourceimpl FulfillmentInstruction
impl FulfillmentInstruction
sourcepub fn new() -> FulfillmentInstruction
pub fn new() -> FulfillmentInstruction
Contains the instructions about the fulfillment like where should it be fulfilled from.